Add nominal noise polynomial to sicd utility (sarpy.utils.nominal_sicd_noise)
=============================================================================

.. automodule:: sarpy.utils.nominal_sicd_noise
    :members:
    :show-inheritance:
    :inherited-members:
